@@ -5,6 +5,9 @@ set -x
 GCC_VERSION=${GCC_VERSION:=9}
 TEST_CFLAGS=
 EXTRA_CFLAGS=
+EXTRA_LDFLAGS=
+SAVED_GITHUB_API_TOKEN="${GITHUB_API_TOKEN}"
+unset GITHUB_API_TOKEN  # remove from env
 
 # Set up compilers
 if [ -z "${OS_NAME##ubuntu*}" ]; then
@@ -20,12 +23,13 @@ if [ -z "${OS_NAME##ubuntu*}" ]; then
   export CC="gcc"
   export PATH="/usr/lib/ccache:$PATH"
   TEST_CFLAGS="-Og -g -fPIC"
-  EXTRA_CFLAGS="$TEST_CFLAGS -Wall -Wextra"
+  EXTRA_CFLAGS="-Wall -Wextra"
 
 elif [ -z "${OS_NAME##macos*}" ]; then
   export CC="clang -Wno-deprecated-declarations"
-  TEST_CFLAGS="-Og -g -fPIC"
-  EXTRA_CFLAGS="$TEST_CFLAGS -Wall -Wextra"
+  TEST_CFLAGS="-Og -g -fPIC -arch arm64 -arch x86_64"
+  EXTRA_LDFLAGS="-arch arm64 -arch x86_64"
+  EXTRA_CFLAGS="-Wall -Wextra -arch arm64 -arch x86_64"
 fi
 
 # Log versions in use
@@ -47,10 +51,13 @@ ccache -s || true
 # Install python requirements
 echo "Installing requirements [python]"
 python -m pip install -U pip setuptools wheel
-if [ -z "${PYTHON_VERSION##*-dev}" ];
-  then python -m pip install --install-option=--cython-compile-minimal https://github.com/cython/cython/archive/master.zip;
-  else python -m pip install -r requirements.txt;
-fi
+
+python -m pip install -r requirements.txt
+#if [ -z "${PYTHON_VERSION##*-dev}" ];
+#  then CYTHON_COMPILE_MINIMAL=true  python -m pip install https://github.com/cython/cython/archive/master.zip;
+#  else python -m pip install -r requirements.txt;
+#fi
+
 if [ -z "${PYTHON_VERSION##2*}" ]; then
   python -m pip install -U beautifulsoup4==4.9.3 cssselect==1.1.0 html5lib==1.1 rnc2rng==2.6.5 ${EXTRA_DEPS} || exit 1
 else
@@ -58,11 +65,14 @@ else
 fi
 if [[ "$COVERAGE" == "true" ]]; then
   python -m pip install "coverage<5" || exit 1
-  python -m pip install --pre 'Cython>=3.0a0' || exit 1
+  python -m pip install --pre 'Cython>=3.0b2' || exit 1
 fi
 
 # Build
-CFLAGS="$CFLAGS $EXTRA_CFLAGS" python -u setup.py build_ext --inplace \
+GITHUB_API_TOKEN="${SAVED_GITHUB_API_TOKEN}" \
+      CFLAGS="$CFLAGS $TEST_CFLAGS $EXTRA_CFLAGS" \
+      LDFLAGS="$LDFLAGS $EXTRA_LDFLAGS" \
+      python -u setup.py build_ext --inplace \
       $(if [ -n "${PYTHON_VERSION##2.*}" ]; then echo -n " -j7 "; fi ) \
       $(if [[ "$COVERAGE" == "true" ]]; then echo -n " --with-coverage"; fi ) \
       || exit 1
@@ -70,14 +80,19 @@ CFLAGS="$CFLAGS $EXTRA_CFLAGS" python -u setup.py build_ext --inplace \
 ccache -s || true
 
 # Run tests
-CFLAGS="$TEST_CFLAGS" PYTHONUNBUFFERED=x make test || exit 1
+echo "Running the tests ..."
+GITHUB_API_TOKEN="${SAVED_GITHUB_API_TOKEN}" \
+      CFLAGS="$TEST_CFLAGS $EXTRA_CFLAGS" \
+      LDFLAGS="$LDFLAGS $EXTRA_LDFLAGS" \
+      PYTHONUNBUFFERED=x \
+      make test || exit 1
 
-python setup.py build || exit 1
-python setup.py install || exit 1
-python -c "from lxml import etree" || exit 1
-
-CFLAGS="-O3 -g1 -mtune=generic -fPIC -flto" \
-  LDFLAGS="-flto" \
-  make clean wheel || exit 1
+if [[ "$COVERAGE" != "true" ]]; then
+  echo "Building a clean wheel ..."
+  GITHUB_API_TOKEN="${SAVED_GITHUB_API_TOKEN}" \
+        CFLAGS="$EXTRA_CFLAGS -O3 -g1 -mtune=generic -fPIC -flto" \
+        LDFLAGS="-flto $EXTRA_LDFLAGS" \
+        make clean wheel || exit 1
+fi
 
 ccache -s || true
